import typing

import android.content
import android.net
import android.net.eap
import android.net.ipsec.ike.exceptions
import android.util
import java
import java.chaquopy
import java.io
import java.lang
import java.net
import java.security
import java.security.cert
import java.util
import java.util.concurrent
import javax.security.auth.x500

class ChildSaProposal(SaProposal):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def getSupportedEncryptionAlgorithms() -> java.util.Set[java.lang.Integer]: ...
    @staticmethod
    def getSupportedIntegrityAlgorithms() -> java.util.Set[java.lang.Integer]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addDhGroup(self, dhGroup: int | java.jint | java.lang.Integer, /) -> ChildSaProposal.Builder: ...
        def addEncryptionAlgorithm(self, algorithm: int | java.jint | java.lang.Integer, keyLength: int | java.jint | java.lang.Integer, /) -> ChildSaProposal.Builder: ...
        def addIntegrityAlgorithm(self, algorithm: int | java.jint | java.lang.Integer, /) -> ChildSaProposal.Builder: ...
        def build(self) -> ChildSaProposal: ...

class ChildSessionCallback(java.lang.Object):
    def onClosed(self) -> None: ...
    def onClosedWithException(self, exception: android.net.ipsec.ike.exceptions.IkeException, /) -> None: ...
    def onIpSecTransformCreated(self, arg1: android.net.IpSecTransform, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def onIpSecTransformDeleted(self, arg1: android.net.IpSecTransform, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOpened(self, arg1: ChildSessionConfiguration, /) -> None: ...

class ChildSessionConfiguration(java.lang.Object):
    def getInboundTrafficSelectors(self) -> java.util.List[IkeTrafficSelector]: ...
    def getOutboundTrafficSelectors(self) -> java.util.List[IkeTrafficSelector]: ...

    class Builder(java.lang.Object):
        def __init__(self, inTs: java.util.List[IkeTrafficSelector], outTs: java.util.List[IkeTrafficSelector], /) -> None: ...
        def build(self) -> ChildSessionConfiguration: ...

class ChildSessionParams(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChildSaProposals(self) -> java.util.List[ChildSaProposal]: ...
    def getHardLifetimeSeconds(self) -> int: ...
    def getInboundTrafficSelectors(self) -> java.util.List[IkeTrafficSelector]: ...
    def getOutboundTrafficSelectors(self) -> java.util.List[IkeTrafficSelector]: ...
    def getSoftLifetimeSeconds(self) -> int: ...
    def hashCode(self) -> int: ...

class IkeDerAsn1DnIdentification(IkeIdentification):
    derAsn1Dn: javax.security.auth.x500.X500Principal = ...
    def __init__(self, derAsn1Dn: javax.security.auth.x500.X500Principal, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class IkeFqdnIdentification(IkeIdentification):
    fqdn: str = ...
    def __init__(self, fqdn: str | java.lang.String, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class IkeIdentification(java.lang.Object): ...

class IkeIpv4AddrIdentification(IkeIdentification):
    ipv4Address: java.net.Inet4Address = ...
    def __init__(self, address: java.net.Inet4Address, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class IkeIpv6AddrIdentification(IkeIdentification):
    ipv6Address: java.net.Inet6Address = ...
    def __init__(self, address: java.net.Inet6Address, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class IkeKeyIdIdentification(IkeIdentification):
    keyId: java.chaquopy.JavaArrayJByte = ...
    def __init__(self, keyId: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class IkeRfc822AddrIdentification(IkeIdentification):
    rfc822Name: str = ...
    def __init__(self, rfc822Name: str | java.lang.String, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class IkeSaProposal(SaProposal):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPseudorandomFunctions(self) -> java.util.List[java.lang.Integer]: ...
    @staticmethod
    def getSupportedEncryptionAlgorithms() -> java.util.Set[java.lang.Integer]: ...
    @staticmethod
    def getSupportedIntegrityAlgorithms() -> java.util.Set[java.lang.Integer]: ...
    @staticmethod
    def getSupportedPseudorandomFunctions() -> java.util.Set[java.lang.Integer]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addDhGroup(self, dhGroup: int | java.jint | java.lang.Integer, /) -> IkeSaProposal.Builder: ...
        def addEncryptionAlgorithm(self, algorithm: int | java.jint | java.lang.Integer, keyLength: int | java.jint | java.lang.Integer, /) -> IkeSaProposal.Builder: ...
        def addIntegrityAlgorithm(self, algorithm: int | java.jint | java.lang.Integer, /) -> IkeSaProposal.Builder: ...
        def addPseudorandomFunction(self, algorithm: int | java.jint | java.lang.Integer, /) -> IkeSaProposal.Builder: ...
        def build(self) -> IkeSaProposal: ...

class IkeSession(java.lang.AutoCloseable):
    def __init__(self, context: android.content.Context, ikeSessionParams: IkeSessionParams, firstChildSessionParams: ChildSessionParams, userCbExecutor: java.util.concurrent.Executor, ikeSessionCallback: IkeSessionCallback, firstChildSessionCallback: ChildSessionCallback, /) -> None: ...
    def close(self) -> None: ...
    def closeChildSession(self, childSessionCallback: ChildSessionCallback, /) -> None: ...
    def dump(self, pw: java.io.PrintWriter, /) -> None: ...
    def finalize(self) -> None: ...
    def kill(self) -> None: ...
    def openChildSession(self, childSessionParams: ChildSessionParams, childSessionCallback: ChildSessionCallback, /) -> None: ...

class IkeSessionCallback(java.lang.Object):
    def onClosed(self) -> None: ...
    def onClosedWithException(self, exception: android.net.ipsec.ike.exceptions.IkeException, /) -> None: ...
    def onError(self, exception: android.net.ipsec.ike.exceptions.IkeException, /) -> None: ...
    def onOpened(self, arg1: IkeSessionConfiguration, /) -> None: ...

class IkeSessionConfiguration(java.lang.Object):
    EXTENSION_TYPE_FRAGMENTATION: typing.ClassVar[int] = ...
    EXTENSION_TYPE_MOBIKE: typing.ClassVar[int] = ...
    def getEapInfo(self) -> android.net.eap.EapInfo | None: ...
    def getIkeSessionConnectionInfo(self) -> IkeSessionConnectionInfo: ...
    def getRemoteApplicationVersion(self) -> str: ...
    def getRemoteVendorIds(self) -> java.util.List[java.chaquopy.JavaArrayJByte]: ...
    def isIkeExtensionEnabled(self, extensionType: int | java.jint | java.lang.Integer, /) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self, ikeConnInfo: IkeSessionConnectionInfo, /) -> None: ...
        def addIkeExtension(self, extensionType: int | java.jint | java.lang.Integer, /) -> IkeSessionConfiguration.Builder: ...
        def addRemoteVendorId(self, remoteVendorId: java.chaquopy.JavaArrayJByte, /) -> IkeSessionConfiguration.Builder: ...
        def build(self) -> IkeSessionConfiguration: ...
        def clearIkeExtensions(self) -> IkeSessionConfiguration.Builder: ...
        def clearRemoteApplicationVersion(self) -> IkeSessionConfiguration.Builder: ...
        def clearRemoteVendorIds(self) -> IkeSessionConfiguration.Builder: ...
        def setEapInfo(self, eapInfo: android.net.eap.EapInfo, /) -> IkeSessionConfiguration.Builder: ...
        def setRemoteApplicationVersion(self, remoteApplicationVersion: str | java.lang.String, /) -> IkeSessionConfiguration.Builder: ...

class IkeSessionConnectionInfo(java.lang.Object):
    def __init__(self, localAddress: java.net.InetAddress, remoteAddress: java.net.InetAddress, network: android.net.Network, /) -> None: ...
    def getLocalAddress(self) -> java.net.InetAddress: ...
    def getNetwork(self) -> android.net.Network: ...
    def getRemoteAddress(self) -> java.net.InetAddress: ...

class IkeSessionParams(java.lang.Object):
    IKE_DPD_DELAY_SEC_DISABLED: typing.ClassVar[int] = ...
    IKE_OPTION_ACCEPT_ANY_REMOTE_ID: typing.ClassVar[int] = ...
    IKE_OPTION_EAP_ONLY_AUTH: typing.ClassVar[int] = ...
    IKE_OPTION_FORCE_PORT_4500: typing.ClassVar[int] = ...
    IKE_OPTION_INITIAL_CONTACT: typing.ClassVar[int] = ...
    IKE_OPTION_MOBIKE: typing.ClassVar[int] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDpdDelaySeconds(self) -> int: ...
    def getHardLifetimeSeconds(self) -> int: ...
    def getIkeOptions(self) -> java.util.Set[java.lang.Integer]: ...
    def getIkeSaProposals(self) -> java.util.List[IkeSaProposal]: ...
    def getLocalAuthConfig(self) -> IkeSessionParams.IkeAuthConfig: ...
    def getLocalIdentification(self) -> IkeIdentification: ...
    def getNattKeepAliveDelaySeconds(self) -> int: ...
    def getNetwork(self) -> android.net.Network | None: ...
    def getRemoteAuthConfig(self) -> IkeSessionParams.IkeAuthConfig: ...
    def getRemoteIdentification(self) -> IkeIdentification: ...
    def getRetransmissionTimeoutsMillis(self) -> java.chaquopy.JavaArrayJInt: ...
    def getServerHostname(self) -> str: ...
    def getSoftLifetimeSeconds(self) -> int: ...
    def hasIkeOption(self, ikeOption: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hashCode(self) -> int: ...

    class IkeAuthPskConfig(IkeSessionParams.IkeAuthConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getPsk(self) -> java.chaquopy.JavaArrayJByte: ...
        def hashCode(self) -> int: ...

    class IkeAuthEapConfig(IkeSessionParams.IkeAuthConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getEapConfig(self) -> android.net.eap.EapSessionConfig: ...
        def hashCode(self) -> int: ...

    class IkeAuthDigitalSignRemoteConfig(IkeSessionParams.IkeAuthConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getRemoteCaCert(self) -> java.security.cert.X509Certificate: ...
        def hashCode(self) -> int: ...

    class IkeAuthDigitalSignLocalConfig(IkeSessionParams.IkeAuthConfig):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getClientEndCertificate(self) -> java.security.cert.X509Certificate: ...
        def getIntermediateCertificates(self) -> java.util.List[java.security.cert.X509Certificate]: ...
        def getPrivateKey(self) -> java.security.PrivateKey: ...
        def hashCode(self) -> int: ...

    class IkeAuthConfig(java.lang.Object):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, ikeSessionParams: IkeSessionParams, /) -> None: ...
        def addIkeOption(self, ikeOption: int | java.jint | java.lang.Integer, /) -> IkeSessionParams.Builder: ...
        def addIkeSaProposal(self, proposal: IkeSaProposal, /) -> IkeSessionParams.Builder: ...
        def build(self) -> IkeSessionParams: ...
        def removeIkeOption(self, ikeOption: int | java.jint | java.lang.Integer, /) -> IkeSessionParams.Builder: ...
        @typing.overload
        def setAuthDigitalSignature(self, serverCaCert: java.security.cert.X509Certificate, clientEndCert: java.security.cert.X509Certificate, clientPrivateKey: java.security.PrivateKey, /) -> IkeSessionParams.Builder: ...
        @typing.overload
        def setAuthDigitalSignature(self, serverCaCert: java.security.cert.X509Certificate, clientEndCert: java.security.cert.X509Certificate, clientIntermediateCerts: java.util.List[java.security.cert.X509Certificate], clientPrivateKey: java.security.PrivateKey, /) -> IkeSessionParams.Builder: ...
        def setAuthEap(self, serverCaCert: java.security.cert.X509Certificate, eapConfig: android.net.eap.EapSessionConfig, /) -> IkeSessionParams.Builder: ...
        def setAuthPsk(self, sharedKey: java.chaquopy.JavaArrayJByte, /) -> IkeSessionParams.Builder: ...
        def setDpdDelaySeconds(self, dpdDelaySeconds: int | java.jint | java.lang.Integer, /) -> IkeSessionParams.Builder: ...
        def setLifetimeSeconds(self, hardLifetimeSeconds: int | java.jint | java.lang.Integer, softLifetimeSeconds: int | java.jint | java.lang.Integer, /) -> IkeSessionParams.Builder: ...
        def setLocalIdentification(self, identification: IkeIdentification, /) -> IkeSessionParams.Builder: ...
        def setNattKeepAliveDelaySeconds(self, nattKeepaliveDelaySeconds: int | java.jint | java.lang.Integer, /) -> IkeSessionParams.Builder: ...
        def setNetwork(self, network: android.net.Network, /) -> IkeSessionParams.Builder: ...
        def setRemoteIdentification(self, identification: IkeIdentification, /) -> IkeSessionParams.Builder: ...
        def setRetransmissionTimeoutsMillis(self, retransTimeoutMillisList: java.chaquopy.JavaArrayJInt, /) -> IkeSessionParams.Builder: ...
        def setServerHostname(self, serverHostname: str | java.lang.String, /) -> IkeSessionParams.Builder: ...

class IkeTrafficSelector(java.lang.Object):
    endPort: int = ...
    endingAddress: java.net.InetAddress = ...
    startPort: int = ...
    startingAddress: java.net.InetAddress = ...
    def __init__(self, startPort: int | java.jint | java.lang.Integer, endPort: int | java.jint | java.lang.Integer, startingAddress: java.net.InetAddress, endingAddress: java.net.InetAddress, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class IkeTunnelConnectionParams(java.lang.Object):
    def __init__(self, ikeParams: IkeSessionParams, childParams: TunnelModeChildSessionParams, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIkeSessionParams(self) -> IkeSessionParams: ...
    def getTunnelModeChildSessionParams(self) -> TunnelModeChildSessionParams: ...
    def hashCode(self) -> int: ...

class SaProposal(java.lang.Object):
    DH_GROUP_1024_BIT_MODP: typing.ClassVar[int] = ...
    DH_GROUP_1536_BIT_MODP: typing.ClassVar[int] = ...
    DH_GROUP_2048_BIT_MODP: typing.ClassVar[int] = ...
    DH_GROUP_3072_BIT_MODP: typing.ClassVar[int] = ...
    DH_GROUP_4096_BIT_MODP: typing.ClassVar[int] = ...
    DH_GROUP_CURVE_25519: typing.ClassVar[int] = ...
    DH_GROUP_NONE: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_3DES: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_AES_CBC: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_AES_CTR: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_AES_GCM_12: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_AES_GCM_16: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_AES_GCM_8: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_CHACHA20_POLY1305: typing.ClassVar[int] = ...
    INTEGRITY_ALGORITHM_AES_CMAC_96: typing.ClassVar[int] = ...
    INTEGRITY_ALGORITHM_AES_XCBC_96: typing.ClassVar[int] = ...
    INTEGRITY_ALGORITHM_HMAC_SHA1_96: typing.ClassVar[int] = ...
    INTEGRITY_ALGORITHM_HMAC_SHA2_256_128: typing.ClassVar[int] = ...
    INTEGRITY_ALGORITHM_HMAC_SHA2_384_192: typing.ClassVar[int] = ...
    INTEGRITY_ALGORITHM_HMAC_SHA2_512_256: typing.ClassVar[int] = ...
    INTEGRITY_ALGORITHM_NONE: typing.ClassVar[int] = ...
    KEY_LEN_AES_128: typing.ClassVar[int] = ...
    KEY_LEN_AES_192: typing.ClassVar[int] = ...
    KEY_LEN_AES_256: typing.ClassVar[int] = ...
    KEY_LEN_UNUSED: typing.ClassVar[int] = ...
    PSEUDORANDOM_FUNCTION_AES128_CMAC: typing.ClassVar[int] = ...
    PSEUDORANDOM_FUNCTION_AES128_XCBC: typing.ClassVar[int] = ...
    PSEUDORANDOM_FUNCTION_HMAC_SHA1: typing.ClassVar[int] = ...
    PSEUDORANDOM_FUNCTION_SHA2_256: typing.ClassVar[int] = ...
    PSEUDORANDOM_FUNCTION_SHA2_384: typing.ClassVar[int] = ...
    PSEUDORANDOM_FUNCTION_SHA2_512: typing.ClassVar[int] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDhGroups(self) -> java.util.List[java.lang.Integer]: ...
    def getEncryptionAlgorithms(self) -> java.util.List[android.util.Pair[java.lang.Integer, java.lang.Integer]]: ...
    def getIntegrityAlgorithms(self) -> java.util.List[java.lang.Integer]: ...
    @staticmethod
    def getSupportedDhGroups() -> java.util.Set[java.lang.Integer]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class TransportModeChildSessionParams(ChildSessionParams):

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, childParams: TransportModeChildSessionParams, /) -> None: ...
        def addChildSaProposal(self, proposal: ChildSaProposal, /) -> TransportModeChildSessionParams.Builder: ...
        def addInboundTrafficSelectors(self, trafficSelector: IkeTrafficSelector, /) -> TransportModeChildSessionParams.Builder: ...
        def addOutboundTrafficSelectors(self, trafficSelector: IkeTrafficSelector, /) -> TransportModeChildSessionParams.Builder: ...
        def build(self) -> TransportModeChildSessionParams: ...
        def setLifetimeSeconds(self, hardLifetimeSeconds: int | java.jint | java.lang.Integer, softLifetimeSeconds: int | java.jint | java.lang.Integer, /) -> TransportModeChildSessionParams.Builder: ...

class TunnelModeChildSessionParams(ChildSessionParams):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getConfigurationRequests(self) -> java.util.List[TunnelModeChildSessionParams.TunnelModeChildConfigRequest]: ...
    def hashCode(self) -> int: ...

    class TunnelModeChildConfigRequest(java.lang.Object): ...

    class ConfigRequestIpv6DnsServer(TunnelModeChildSessionParams.TunnelModeChildConfigRequest): ...

    class ConfigRequestIpv6Address(TunnelModeChildSessionParams.TunnelModeChildConfigRequest):
        def getAddress(self) -> java.net.Inet6Address: ...
        def getPrefixLength(self) -> int: ...

    class ConfigRequestIpv4Netmask(TunnelModeChildSessionParams.TunnelModeChildConfigRequest): ...

    class ConfigRequestIpv4DnsServer(TunnelModeChildSessionParams.TunnelModeChildConfigRequest): ...

    class ConfigRequestIpv4DhcpServer(TunnelModeChildSessionParams.TunnelModeChildConfigRequest): ...

    class ConfigRequestIpv4Address(TunnelModeChildSessionParams.TunnelModeChildConfigRequest):
        def getAddress(self) -> java.net.Inet4Address: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, childParams: TunnelModeChildSessionParams, /) -> None: ...
        def addChildSaProposal(self, proposal: ChildSaProposal, /) -> TunnelModeChildSessionParams.Builder: ...
        def addInboundTrafficSelectors(self, trafficSelector: IkeTrafficSelector, /) -> TunnelModeChildSessionParams.Builder: ...
        @typing.overload
        def addInternalAddressRequest(self, addressFamily: int | java.jint | java.lang.Integer, /) -> TunnelModeChildSessionParams.Builder: ...
        @typing.overload
        def addInternalAddressRequest(self, address: java.net.Inet4Address, /) -> TunnelModeChildSessionParams.Builder: ...
        @typing.overload
        def addInternalAddressRequest(self, address: java.net.Inet6Address, prefixLen: int | java.jint | java.lang.Integer, /) -> TunnelModeChildSessionParams.Builder: ...
        def addInternalDhcpServerRequest(self, addressFamily: int | java.jint | java.lang.Integer, /) -> TunnelModeChildSessionParams.Builder: ...
        def addInternalDnsServerRequest(self, addressFamily: int | java.jint | java.lang.Integer, /) -> TunnelModeChildSessionParams.Builder: ...
        def addOutboundTrafficSelectors(self, trafficSelector: IkeTrafficSelector, /) -> TunnelModeChildSessionParams.Builder: ...
        def build(self) -> TunnelModeChildSessionParams: ...
        def setLifetimeSeconds(self, hardLifetimeSeconds: int | java.jint | java.lang.Integer, softLifetimeSeconds: int | java.jint | java.lang.Integer, /) -> TunnelModeChildSessionParams.Builder: ...



import typing

import android.adservices.common
import android.content
import android.net
import android.os
import java
import java.lang
import java.time
import java.util
import java.util.concurrent

class AddCustomAudienceOverrideRequest(java.lang.Object):
    def __init__(self, buyer: android.adservices.common.AdTechIdentifier, name: str | java.lang.String, biddingLogicJs: str | java.lang.String, trustedBiddingSignals: android.adservices.common.AdSelectionSignals, /) -> None: ...
    def getBiddingLogicJs(self) -> str: ...
    def getBiddingLogicJsVersion(self) -> int: ...
    def getBuyer(self) -> android.adservices.common.AdTechIdentifier: ...
    def getName(self) -> str: ...
    def getTrustedBiddingSignals(self) -> android.adservices.common.AdSelectionSignals: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AddCustomAudienceOverrideRequest: ...
        def setBiddingLogicJs(self, biddingLogicJs: str | java.lang.String, /) -> AddCustomAudienceOverrideRequest.Builder: ...
        def setBiddingLogicJsVersion(self, biddingLogicJsVersion: int | java.jlong | java.lang.Long, /) -> AddCustomAudienceOverrideRequest.Builder: ...
        def setBuyer(self, buyer: android.adservices.common.AdTechIdentifier, /) -> AddCustomAudienceOverrideRequest.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> AddCustomAudienceOverrideRequest.Builder: ...
        def setTrustedBiddingSignals(self, trustedBiddingSignals: android.adservices.common.AdSelectionSignals, /) -> AddCustomAudienceOverrideRequest.Builder: ...

class CustomAudience(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CustomAudience]] = ...
    FLAG_AUCTION_SERVER_REQUEST_OMIT_ADS: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActivationTime(self) -> java.time.Instant | None: ...
    def getAds(self) -> java.util.List[android.adservices.common.AdData]: ...
    def getAuctionServerRequestFlags(self) -> int: ...
    def getBiddingLogicUri(self) -> android.net.Uri: ...
    def getBuyer(self) -> android.adservices.common.AdTechIdentifier: ...
    def getComponentAds(self) -> java.util.List[android.adservices.common.ComponentAdData]: ...
    def getDailyUpdateUri(self) -> android.net.Uri: ...
    def getExpirationTime(self) -> java.time.Instant | None: ...
    def getName(self) -> str: ...
    def getPriority(self) -> float: ...
    def getTrustedBiddingData(self) -> TrustedBiddingData | None: ...
    def getUserBiddingSignals(self) -> android.adservices.common.AdSelectionSignals | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> CustomAudience: ...
        def setActivationTime(self, activationTime: java.time.Instant, /) -> CustomAudience.Builder: ...
        def setAds(self, ads: java.util.List[android.adservices.common.AdData], /) -> CustomAudience.Builder: ...
        def setAuctionServerRequestFlags(self, auctionServerRequestFlags: int | java.jint | java.lang.Integer, /) -> CustomAudience.Builder: ...
        def setBiddingLogicUri(self, biddingLogicUri: android.net.Uri, /) -> CustomAudience.Builder: ...
        def setBuyer(self, buyer: android.adservices.common.AdTechIdentifier, /) -> CustomAudience.Builder: ...
        def setComponentAds(self, componentAds: java.util.List[android.adservices.common.ComponentAdData], /) -> CustomAudience.Builder: ...
        def setDailyUpdateUri(self, dailyUpdateUri: android.net.Uri, /) -> CustomAudience.Builder: ...
        def setExpirationTime(self, expirationTime: java.time.Instant, /) -> CustomAudience.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> CustomAudience.Builder: ...
        def setPriority(self, priority: float | java.jdouble | java.lang.Double, /) -> CustomAudience.Builder: ...
        def setTrustedBiddingData(self, trustedBiddingData: TrustedBiddingData, /) -> CustomAudience.Builder: ...
        def setUserBiddingSignals(self, userBiddingSignals: android.adservices.common.AdSelectionSignals, /) -> CustomAudience.Builder: ...

class CustomAudienceManager(java.lang.Object):
    def fetchAndJoinCustomAudience(self, fetchAndJoinCustomAudienceRequest: FetchAndJoinCustomAudienceRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @staticmethod
    def get(context: android.content.Context, /) -> CustomAudienceManager: ...
    def getTestCustomAudienceManager(self) -> TestCustomAudienceManager: ...
    def joinCustomAudience(self, joinCustomAudienceRequest: JoinCustomAudienceRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def leaveCustomAudience(self, leaveCustomAudienceRequest: LeaveCustomAudienceRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def scheduleCustomAudienceUpdate(self, request: ScheduleCustomAudienceUpdateRequest, executor: java.util.concurrent.Executor, receiver: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...

class FetchAndJoinCustomAudienceRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActivationTime(self) -> java.time.Instant | None: ...
    def getExpirationTime(self) -> java.time.Instant | None: ...
    def getFetchUri(self) -> android.net.Uri: ...
    def getName(self) -> str | None: ...
    def getUserBiddingSignals(self) -> android.adservices.common.AdSelectionSignals | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self, fetchUri: android.net.Uri, /) -> None: ...
        def build(self) -> FetchAndJoinCustomAudienceRequest: ...
        def setActivationTime(self, activationTime: java.time.Instant, /) -> FetchAndJoinCustomAudienceRequest.Builder: ...
        def setExpirationTime(self, expirationTime: java.time.Instant, /) -> FetchAndJoinCustomAudienceRequest.Builder: ...
        def setFetchUri(self, fetchUri: android.net.Uri, /) -> FetchAndJoinCustomAudienceRequest.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> FetchAndJoinCustomAudienceRequest.Builder: ...
        def setUserBiddingSignals(self, userBiddingSignals: android.adservices.common.AdSelectionSignals, /) -> FetchAndJoinCustomAudienceRequest.Builder: ...

class JoinCustomAudienceRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCustomAudience(self) -> CustomAudience: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> JoinCustomAudienceRequest: ...
        def setCustomAudience(self, customAudience: CustomAudience, /) -> JoinCustomAudienceRequest.Builder: ...

class LeaveCustomAudienceRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBuyer(self) -> android.adservices.common.AdTechIdentifier: ...
    def getName(self) -> str: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> LeaveCustomAudienceRequest: ...
        def setBuyer(self, buyer: android.adservices.common.AdTechIdentifier, /) -> LeaveCustomAudienceRequest.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> LeaveCustomAudienceRequest.Builder: ...

class PartialCustomAudience(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PartialCustomAudience]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActivationTime(self) -> java.time.Instant | None: ...
    def getExpirationTime(self) -> java.time.Instant | None: ...
    def getName(self) -> str: ...
    def getUserBiddingSignals(self) -> android.adservices.common.AdSelectionSignals | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        def build(self) -> PartialCustomAudience: ...
        def setActivationTime(self, activationTime: java.time.Instant, /) -> PartialCustomAudience.Builder: ...
        def setExpirationTime(self, expirationTime: java.time.Instant, /) -> PartialCustomAudience.Builder: ...
        def setUserBiddingSignals(self, userBiddingSignals: android.adservices.common.AdSelectionSignals, /) -> PartialCustomAudience.Builder: ...

class RemoveCustomAudienceOverrideRequest(java.lang.Object):
    def __init__(self, buyer: android.adservices.common.AdTechIdentifier, name: str | java.lang.String, /) -> None: ...
    def getBuyer(self) -> android.adservices.common.AdTechIdentifier: ...
    def getName(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> RemoveCustomAudienceOverrideRequest: ...
        def setBuyer(self, buyer: android.adservices.common.AdTechIdentifier, /) -> RemoveCustomAudienceOverrideRequest.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> RemoveCustomAudienceOverrideRequest.Builder: ...

class ScheduleCustomAudienceUpdateRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMinDelay(self) -> java.time.Duration: ...
    def getPartialCustomAudienceList(self) -> java.util.List[PartialCustomAudience]: ...
    def getUpdateUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def shouldReplacePendingUpdates(self) -> bool: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, updateUri: android.net.Uri, minDelay: java.time.Duration, /) -> None: ...
        @typing.overload
        def __init__(self, updateUri: android.net.Uri, minDelay: java.time.Duration, partialCustomAudienceList: java.util.List[PartialCustomAudience], /) -> None: ...
        def build(self) -> ScheduleCustomAudienceUpdateRequest: ...
        def setMinDelay(self, minDelay: java.time.Duration, /) -> ScheduleCustomAudienceUpdateRequest.Builder: ...
        def setPartialCustomAudienceList(self, partialCustomAudienceList: java.util.List[PartialCustomAudience], /) -> ScheduleCustomAudienceUpdateRequest.Builder: ...
        def setShouldReplacePendingUpdates(self, shouldReplacePendingUpdates: bool | java.jboolean | java.lang.Boolean, /) -> ScheduleCustomAudienceUpdateRequest.Builder: ...
        def setUpdateUri(self, updateUri: android.net.Uri, /) -> ScheduleCustomAudienceUpdateRequest.Builder: ...

class TestCustomAudienceManager(java.lang.Object):
    def overrideCustomAudienceRemoteInfo(self, request: AddCustomAudienceOverrideRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def removeCustomAudienceRemoteInfoOverride(self, request: RemoveCustomAudienceOverrideRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def resetAllCustomAudienceOverrides(self, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...

class TrustedBiddingData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TrustedBiddingData]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getTrustedBiddingKeys(self) -> java.util.List[java.lang.String]: ...
    def getTrustedBiddingUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> TrustedBiddingData: ...
        def setTrustedBiddingKeys(self, trustedBiddingKeys: java.util.List[java.lang.String], /) -> TrustedBiddingData.Builder: ...
        def setTrustedBiddingUri(self, trustedBiddingUri: android.net.Uri, /) -> TrustedBiddingData.Builder: ...



import typing

import android.os
import android.telephony.ims.feature
import java
import java.lang
import java.util
import java.util.concurrent
import java.util.function

class ImsException(java.lang.Exception):
    CODE_ERROR_INVALID_SUBSCRIPTION: typing.ClassVar[int] = ...
    CODE_ERROR_SERVICE_UNAVAILABLE: typing.ClassVar[int] = ...
    CODE_ERROR_UNSPECIFIED: typing.ClassVar[int] = ...
    CODE_ERROR_UNSUPPORTED_OPERATION: typing.ClassVar[int] = ...
    def getCode(self) -> int: ...

class ImsManager(java.lang.Object):
    ACTION_WFC_IMS_REGISTRATION_ERROR: typing.ClassVar[str] = ...
    EXTRA_WFC_REGISTRATION_FAILURE_MESSAGE: typing.ClassVar[str] = ...
    EXTRA_WFC_REGISTRATION_FAILURE_TITLE: typing.ClassVar[str] = ...
    def getImsMmTelManager(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> ImsMmTelManager: ...
    def getImsRcsManager(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> ImsRcsManager: ...
    def getProvisioningManager(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> ProvisioningManager: ...

class ImsMmTelManager(RegistrationManager):
    WIFI_MODE_CELLULAR_PREFERRED: typing.ClassVar[int] = ...
    WIFI_MODE_WIFI_ONLY: typing.ClassVar[int] = ...
    WIFI_MODE_WIFI_PREFERRED: typing.ClassVar[int] = ...
    def getRegistrationState(self, executor: java.util.concurrent.Executor, stateCallback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def getRegistrationTransportType(self, executor: java.util.concurrent.Executor, transportTypeCallback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def getVoWiFiModeSetting(self) -> int: ...
    def isAdvancedCallingSettingEnabled(self) -> bool: ...
    def isCrossSimCallingEnabled(self) -> bool: ...
    def isTtyOverVolteEnabled(self) -> bool: ...
    def isVoWiFiRoamingSettingEnabled(self) -> bool: ...
    def isVoWiFiSettingEnabled(self) -> bool: ...
    def isVtSettingEnabled(self) -> bool: ...
    def registerImsRegistrationCallback(self, executor: java.util.concurrent.Executor, c: RegistrationManager.RegistrationCallback, /) -> None: ...
    def registerImsStateCallback(self, executor: java.util.concurrent.Executor, callback: ImsStateCallback, /) -> None: ...
    def registerMmTelCapabilityCallback(self, executor: java.util.concurrent.Executor, c: ImsMmTelManager.CapabilityCallback, /) -> None: ...
    def unregisterImsRegistrationCallback(self, c: RegistrationManager.RegistrationCallback, /) -> None: ...
    def unregisterImsStateCallback(self, callback: ImsStateCallback, /) -> None: ...
    def unregisterMmTelCapabilityCallback(self, c: ImsMmTelManager.CapabilityCallback, /) -> None: ...

    class CapabilityCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onCapabilitiesStatusChanged(self, capabilities: android.telephony.ims.feature.MmTelFeature.MmTelCapabilities, /) -> None: ...

class ImsRcsManager(java.lang.Object):
    ACTION_SHOW_CAPABILITY_DISCOVERY_OPT_IN: typing.ClassVar[str] = ...
    CAPABILITY_TYPE_NONE: typing.ClassVar[int] = ...
    CAPABILITY_TYPE_OPTIONS_UCE: typing.ClassVar[int] = ...
    CAPABILITY_TYPE_PRESENCE_UCE: typing.ClassVar[int] = ...
    def getRegistrationState(self, executor: java.util.concurrent.Executor, stateCallback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def getRegistrationTransportType(self, executor: java.util.concurrent.Executor, transportTypeCallback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def getUceAdapter(self) -> RcsUceAdapter: ...
    def registerImsRegistrationCallback(self, executor: java.util.concurrent.Executor, c: RegistrationManager.RegistrationCallback, /) -> None: ...
    def registerImsStateCallback(self, executor: java.util.concurrent.Executor, callback: ImsStateCallback, /) -> None: ...
    def unregisterImsRegistrationCallback(self, c: RegistrationManager.RegistrationCallback, /) -> None: ...
    def unregisterImsStateCallback(self, callback: ImsStateCallback, /) -> None: ...

class ImsReasonInfo(android.os.Parcelable):
    CODE_ACCESS_CLASS_BLOCKED: typing.ClassVar[int] = ...
    CODE_ANSWERED_ELSEWHERE: typing.ClassVar[int] = ...
    CODE_BLACKLISTED_CALL_ID: typing.ClassVar[int] = ...
    CODE_CALL_BARRED: typing.ClassVar[int] = ...
    CODE_CALL_DROP_IWLAN_TO_LTE_UNAVAILABLE: typing.ClassVar[int] = ...
    CODE_CALL_END_CAUSE_CALL_PULL: typing.ClassVar[int] = ...
    CODE_CALL_PULL_OUT_OF_SYNC: typing.ClassVar[int] = ...
    CODE_DATA_DISABLED: typing.ClassVar[int] = ...
    CODE_DATA_LIMIT_REACHED: typing.ClassVar[int] = ...
    CODE_DIAL_MODIFIED_TO_DIAL: typing.ClassVar[int] = ...
    CODE_DIAL_MODIFIED_TO_DIAL_VIDEO: typing.ClassVar[int] = ...
    CODE_DIAL_MODIFIED_TO_SS: typing.ClassVar[int] = ...
    CODE_DIAL_MODIFIED_TO_USSD: typing.ClassVar[int] = ...
    CODE_DIAL_VIDEO_MODIFIED_TO_DIAL: typing.ClassVar[int] = ...
    CODE_DIAL_VIDEO_MODIFIED_TO_DIAL_VIDEO: typing.ClassVar[int] = ...
    CODE_DIAL_VIDEO_MODIFIED_TO_SS: typing.ClassVar[int] = ...
    CODE_DIAL_VIDEO_MODIFIED_TO_USSD: typing.ClassVar[int] = ...
    CODE_ECBM_NOT_SUPPORTED: typing.ClassVar[int] = ...
    CODE_EMERGENCY_PERM_FAILURE: typing.ClassVar[int] = ...
    CODE_EMERGENCY_TEMP_FAILURE: typing.ClassVar[int] = ...
    CODE_EPDG_TUNNEL_ESTABLISH_FAILURE: typing.ClassVar[int] = ...
    CODE_EPDG_TUNNEL_LOST_CONNECTION: typing.ClassVar[int] = ...
    CODE_EPDG_TUNNEL_REKEY_FAILURE: typing.ClassVar[int] = ...
    CODE_FDN_BLOCKED: typing.ClassVar[int] = ...
    CODE_IKEV2_AUTH_FAILURE: typing.ClassVar[int] = ...
    CODE_IMEI_NOT_ACCEPTED: typing.ClassVar[int] = ...
    CODE_IWLAN_DPD_FAILURE: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_BUSY: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_CS_RETRY_REQUIRED: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_DECLINE: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_EXCEEDED: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_RESOURCE_RESERVATION_FAILED: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_TERMINATED: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_VCC_ON_PROGRESSING: typing.ClassVar[int] = ...
    CODE_LOCAL_CALL_VOLTE_RETRY_REQUIRED: typing.ClassVar[int] = ...
    CODE_LOCAL_ENDED_BY_CONFERENCE_MERGE: typing.ClassVar[int] = ...
    CODE_LOCAL_HO_NOT_FEASIBLE: typing.ClassVar[int] = ...
    CODE_LOCAL_ILLEGAL_ARGUMENT: typing.ClassVar[int] = ...
    CODE_LOCAL_ILLEGAL_STATE: typing.ClassVar[int] = ...
    CODE_LOCAL_IMS_SERVICE_DOWN: typing.ClassVar[int] = ...
    CODE_LOCAL_INTERNAL_ERROR: typing.ClassVar[int] = ...
    CODE_LOCAL_LOW_BATTERY: typing.ClassVar[int] = ...
    CODE_LOCAL_NETWORK_IP_CHANGED: typing.ClassVar[int] = ...
    CODE_LOCAL_NETWORK_NO_LTE_COVERAGE: typing.ClassVar[int] = ...
    CODE_LOCAL_NETWORK_NO_SERVICE: typing.ClassVar[int] = ...
    CODE_LOCAL_NETWORK_ROAMING: typing.ClassVar[int] = ...
    CODE_LOCAL_NOT_REGISTERED: typing.ClassVar[int] = ...
    CODE_LOCAL_NO_PENDING_CALL: typing.ClassVar[int] = ...
    CODE_LOCAL_POWER_OFF: typing.ClassVar[int] = ...
    CODE_LOCAL_SERVICE_UNAVAILABLE: typing.ClassVar[int] = ...
    CODE_LOW_BATTERY: typing.ClassVar[int] = ...
    CODE_MAXIMUM_NUMBER_OF_CALLS_REACHED: typing.ClassVar[int] = ...
    CODE_MEDIA_INIT_FAILED: typing.ClassVar[int] = ...
    CODE_MEDIA_NOT_ACCEPTABLE: typing.ClassVar[int] = ...
    CODE_MEDIA_NO_DATA: typing.ClassVar[int] = ...
    CODE_MEDIA_UNSPECIFIED: typing.ClassVar[int] = ...
    CODE_MULTIENDPOINT_NOT_SUPPORTED: typing.ClassVar[int] = ...
    CODE_NETWORK_CONGESTION: typing.ClassVar[int] = ...
    CODE_NETWORK_DETACH: typing.ClassVar[int] = ...
    CODE_NETWORK_REJECT: typing.ClassVar[int] = ...
    CODE_NETWORK_RESP_TIMEOUT: typing.ClassVar[int] = ...
    CODE_NO_CSFB_IN_CS_ROAM: typing.ClassVar[int] = ...
    CODE_NO_VALID_SIM: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_10: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_11: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_12: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_13: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_14: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_15: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_1: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_2: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_3: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_4: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_5: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_6: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_7: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_8: typing.ClassVar[int] = ...
    CODE_OEM_CAUSE_9: typing.ClassVar[int] = ...
    CODE_RADIO_ACCESS_FAILURE: typing.ClassVar[int] = ...
    CODE_RADIO_INTERNAL_ERROR: typing.ClassVar[int] = ...
    CODE_RADIO_LINK_FAILURE: typing.ClassVar[int] = ...
    CODE_RADIO_LINK_LOST: typing.ClassVar[int] = ...
    CODE_RADIO_OFF: typing.ClassVar[int] = ...
    CODE_RADIO_RELEASE_ABNORMAL: typing.ClassVar[int] = ...
    CODE_RADIO_RELEASE_NORMAL: typing.ClassVar[int] = ...
    CODE_RADIO_SETUP_FAILURE: typing.ClassVar[int] = ...
    CODE_RADIO_UPLINK_FAILURE: typing.ClassVar[int] = ...
    CODE_REGISTRATION_ERROR: typing.ClassVar[int] = ...
    CODE_REJECTED_ELSEWHERE: typing.ClassVar[int] = ...
    CODE_REJECT_1X_COLLISION: typing.ClassVar[int] = ...
    CODE_REJECT_CALL_ON_OTHER_SUB: typing.ClassVar[int] = ...
    CODE_REJECT_CALL_TYPE_NOT_ALLOWED: typing.ClassVar[int] = ...
    CODE_REJECT_CONFERENCE_TTY_NOT_ALLOWED: typing.ClassVar[int] = ...
    CODE_REJECT_INTERNAL_ERROR: typing.ClassVar[int] = ...
    CODE_REJECT_MAX_CALL_LIMIT_REACHED: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_CALL_SETUP: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_CALL_TRANSFER: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_CALL_UPGRADE: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_CALL_WAITING_DISABLED: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_CONFERENCE_CALL: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_CS_CALL: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_E911_CALL: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_ENCRYPTED_CALL: typing.ClassVar[int] = ...
    CODE_REJECT_ONGOING_HANDOVER: typing.ClassVar[int] = ...
    CODE_REJECT_QOS_FAILURE: typing.ClassVar[int] = ...
    CODE_REJECT_SERVICE_NOT_REGISTERED: typing.ClassVar[int] = ...
    CODE_REJECT_UNKNOWN: typing.ClassVar[int] = ...
    CODE_REJECT_UNSUPPORTED_SDP_HEADERS: typing.ClassVar[int] = ...
    CODE_REJECT_UNSUPPORTED_SIP_HEADERS: typing.ClassVar[int] = ...
    CODE_REJECT_VT_AVPF_NOT_ALLOWED: typing.ClassVar[int] = ...
    CODE_REJECT_VT_TTY_NOT_ALLOWED: typing.ClassVar[int] = ...
    CODE_REMOTE_CALL_DECLINE: typing.ClassVar[int] = ...
    CODE_SESSION_MODIFICATION_FAILED: typing.ClassVar[int] = ...
    CODE_SIP_ALTERNATE_EMERGENCY_CALL: typing.ClassVar[int] = ...
    CODE_SIP_AMBIGUOUS: typing.ClassVar[int] = ...
    CODE_SIP_BAD_ADDRESS: typing.ClassVar[int] = ...
    CODE_SIP_BAD_REQUEST: typing.ClassVar[int] = ...
    CODE_SIP_BUSY: typing.ClassVar[int] = ...
    CODE_SIP_CALL_OR_TRANS_DOES_NOT_EXIST: typing.ClassVar[int] = ...
    CODE_SIP_CLIENT_ERROR: typing.ClassVar[int] = ...
    CODE_SIP_EXTENSION_REQUIRED: typing.ClassVar[int] = ...
    CODE_SIP_FORBIDDEN: typing.ClassVar[int] = ...
    CODE_SIP_GLOBAL_ERROR: typing.ClassVar[int] = ...
    CODE_SIP_INTERVAL_TOO_BRIEF: typing.ClassVar[int] = ...
    CODE_SIP_LOOP_DETECTED: typing.ClassVar[int] = ...
    CODE_SIP_METHOD_NOT_ALLOWED: typing.ClassVar[int] = ...
    CODE_SIP_NOT_ACCEPTABLE: typing.ClassVar[int] = ...
    CODE_SIP_NOT_FOUND: typing.ClassVar[int] = ...
    CODE_SIP_NOT_REACHABLE: typing.ClassVar[int] = ...
    CODE_SIP_NOT_SUPPORTED: typing.ClassVar[int] = ...
    CODE_SIP_PROXY_AUTHENTICATION_REQUIRED: typing.ClassVar[int] = ...
    CODE_SIP_REDIRECTED: typing.ClassVar[int] = ...
    CODE_SIP_REQUEST_CANCELLED: typing.ClassVar[int] = ...
    CODE_SIP_REQUEST_ENTITY_TOO_LARGE: typing.ClassVar[int] = ...
    CODE_SIP_REQUEST_PENDING: typing.ClassVar[int] = ...
    CODE_SIP_REQUEST_TIMEOUT: typing.ClassVar[int] = ...
    CODE_SIP_REQUEST_URI_TOO_LARGE: typing.ClassVar[int] = ...
    CODE_SIP_SERVER_ERROR: typing.ClassVar[int] = ...
    CODE_SIP_SERVER_INTERNAL_ERROR: typing.ClassVar[int] = ...
    CODE_SIP_SERVER_TIMEOUT: typing.ClassVar[int] = ...
    CODE_SIP_SERVICE_UNAVAILABLE: typing.ClassVar[int] = ...
    CODE_SIP_TEMPRARILY_UNAVAILABLE: typing.ClassVar[int] = ...
    CODE_SIP_TOO_MANY_HOPS: typing.ClassVar[int] = ...
    CODE_SIP_TRANSACTION_DOES_NOT_EXIST: typing.ClassVar[int] = ...
    CODE_SIP_UNDECIPHERABLE: typing.ClassVar[int] = ...
    CODE_SIP_USER_MARKED_UNWANTED: typing.ClassVar[int] = ...
    CODE_SIP_USER_REJECTED: typing.ClassVar[int] = ...
    CODE_SUPP_SVC_CANCELLED: typing.ClassVar[int] = ...
    CODE_SUPP_SVC_FAILED: typing.ClassVar[int] = ...
    CODE_SUPP_SVC_REINVITE_COLLISION: typing.ClassVar[int] = ...
    CODE_TIMEOUT_1XX_WAITING: typing.ClassVar[int] = ...
    CODE_TIMEOUT_NO_ANSWER: typing.ClassVar[int] = ...
    CODE_TIMEOUT_NO_ANSWER_CALL_UPDATE: typing.ClassVar[int] = ...
    CODE_UNSPECIFIED: typing.ClassVar[int] = ...
    CODE_USER_CANCELLED_SESSION_MODIFICATION: typing.ClassVar[int] = ...
    CODE_USER_DECLINE: typing.ClassVar[int] = ...
    CODE_USER_IGNORE: typing.ClassVar[int] = ...
    CODE_USER_NOANSWER: typing.ClassVar[int] = ...
    CODE_USER_REJECTED_SESSION_MODIFICATION: typing.ClassVar[int] = ...
    CODE_USER_TERMINATED: typing.ClassVar[int] = ...
    CODE_USER_TERMINATED_BY_REMOTE: typing.ClassVar[int] = ...
    CODE_UT_CB_PASSWORD_MISMATCH: typing.ClassVar[int] = ...
    CODE_UT_NETWORK_ERROR: typing.ClassVar[int] = ...
    CODE_UT_NOT_SUPPORTED: typing.ClassVar[int] = ...
    CODE_UT_OPERATION_NOT_ALLOWED: typing.ClassVar[int] = ...
    CODE_UT_SERVICE_UNAVAILABLE: typing.ClassVar[int] = ...
    CODE_UT_SS_MODIFIED_TO_DIAL: typing.ClassVar[int] = ...
    CODE_UT_SS_MODIFIED_TO_DIAL_VIDEO: typing.ClassVar[int] = ...
    CODE_UT_SS_MODIFIED_TO_SS: typing.ClassVar[int] = ...
    CODE_UT_SS_MODIFIED_TO_USSD: typing.ClassVar[int] = ...
    CODE_WIFI_LOST: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ImsReasonInfo]] = ...
    EXTRA_CODE_CALL_RETRY_BY_SETTINGS: typing.ClassVar[int] = ...
    EXTRA_CODE_CALL_RETRY_EMERGENCY: typing.ClassVar[int] = ...
    EXTRA_CODE_CALL_RETRY_NORMAL: typing.ClassVar[int] = ...
    EXTRA_CODE_CALL_RETRY_SILENT_REDIAL: typing.ClassVar[int] = ...
    def __init__(self, code: int | java.jint | java.lang.Integer, extraCode: int | java.jint | java.lang.Integer, extraMessage: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCode(self) -> int: ...
    def getExtraCode(self) -> int: ...
    def getExtraMessage(self) -> str | None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ImsRegistrationAttributes(android.os.Parcelable):
    ATTR_EPDG_OVER_CELL_INTERNET: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ImsRegistrationAttributes]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAttributeFlags(self) -> int: ...
    def getFeatureTags(self) -> java.util.Set[java.lang.String]: ...
    def getSipDetails(self) -> SipDetails | None: ...
    def getTransportType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ImsStateCallback(java.lang.Object):
    REASON_IMS_SERVICE_DISCONNECTED: typing.ClassVar[int] = ...
    REASON_IMS_SERVICE_NOT_READY: typing.ClassVar[int] = ...
    REASON_NO_IMS_SERVICE_CONFIGURED: typing.ClassVar[int] = ...
    REASON_SUBSCRIPTION_INACTIVE: typing.ClassVar[int] = ...
    REASON_UNKNOWN_PERMANENT_ERROR: typing.ClassVar[int] = ...
    REASON_UNKNOWN_TEMPORARY_ERROR: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onAvailable(self) -> None: ...
    def onError(self) -> None: ...
    def onUnavailable(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class ProvisioningManager(java.lang.Object):
    def getProvisioningStatusForCapability(self, capability: int | java.jint | java.lang.Integer, tech: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getRcsProvisioningStatusForCapability(self, capability: int | java.jint | java.lang.Integer, tech: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isProvisioningRequiredForCapability(self, capability: int | java.jint | java.lang.Integer, tech: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isRcsProvisioningRequiredForCapability(self, capability: int | java.jint | java.lang.Integer, tech: int | java.jint | java.lang.Integer, /) -> bool: ...
    def registerFeatureProvisioningChangedCallback(self, executor: java.util.concurrent.Executor, callback: ProvisioningManager.FeatureProvisioningCallback, /) -> None: ...
    def setProvisioningStatusForCapability(self, capability: int | java.jint | java.lang.Integer, tech: int | java.jint | java.lang.Integer, isProvisioned: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRcsProvisioningStatusForCapability(self, capability: int | java.jint | java.lang.Integer, tech: int | java.jint | java.lang.Integer, isProvisioned: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def unregisterFeatureProvisioningChangedCallback(self, callback: ProvisioningManager.FeatureProvisioningCallback, /) -> None: ...

    class FeatureProvisioningCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onFeatureProvisioningChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onRcsFeatureProvisioningChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class RcsUceAdapter(java.lang.Object):
    def isUceSettingEnabled(self) -> bool: ...

class RegistrationManager(java.lang.Object):
    REGISTRATION_STATE_NOT_REGISTERED: typing.ClassVar[int] = ...
    REGISTRATION_STATE_REGISTERED: typing.ClassVar[int] = ...
    REGISTRATION_STATE_REGISTERING: typing.ClassVar[int] = ...
    def getRegistrationState(self, arg1: java.util.concurrent.Executor, arg2: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def getRegistrationTransportType(self, arg1: java.util.concurrent.Executor, arg2: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def registerImsRegistrationCallback(self, arg1: java.util.concurrent.Executor, arg2: RegistrationManager.RegistrationCallback, /) -> None: ...
    def unregisterImsRegistrationCallback(self, arg1: RegistrationManager.RegistrationCallback, /) -> None: ...

    class RegistrationCallback(java.lang.Object):
        def __init__(self) -> None: ...
        @typing.overload
        def onRegistered(self, imsTransportType: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def onRegistered(self, attributes: ImsRegistrationAttributes, /) -> None: ...
        @typing.overload
        def onRegistering(self, imsTransportType: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def onRegistering(self, attributes: ImsRegistrationAttributes, /) -> None: ...
        def onTechnologyChangeFailed(self, imsTransportType: int | java.jint | java.lang.Integer, info: ImsReasonInfo, /) -> None: ...
        def onUnregistered(self, info: ImsReasonInfo, /) -> None: ...

class SipDetails(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SipDetails]] = ...
    METHOD_PUBLISH: typing.ClassVar[int] = ...
    METHOD_REGISTER: typing.ClassVar[int] = ...
    METHOD_SUBSCRIBE: typing.ClassVar[int] = ...
    METHOD_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCSeq(self) -> int: ...
    def getCallId(self) -> str | None: ...
    def getMethod(self) -> int: ...
    def getReasonHeaderCause(self) -> int: ...
    def getReasonHeaderText(self) -> str: ...
    def getResponseCode(self) -> int: ...
    def getResponsePhrase(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.content
import android.net.ipsec.ike
import android.os
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class VcnCellUnderlyingNetworkTemplate(VcnUnderlyingNetworkTemplate):
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCbs(self) -> int: ...
    def getDun(self) -> int: ...
    def getIms(self) -> int: ...
    def getInternet(self) -> int: ...
    def getMms(self) -> int: ...
    def getOperatorPlmnIds(self) -> java.util.Set[java.lang.String]: ...
    def getOpportunistic(self) -> int: ...
    def getRcs(self) -> int: ...
    def getRoaming(self) -> int: ...
    def getSimSpecificCarrierIds(self) -> java.util.Set[java.lang.Integer]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> VcnCellUnderlyingNetworkTemplate: ...
        def setCbs(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setDun(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setIms(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setInternet(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setMetered(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setMinDownstreamBandwidthKbps(self, minEntryDownstreamBandwidthKbps: int | java.jint | java.lang.Integer, minExitDownstreamBandwidthKbps: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setMinUpstreamBandwidthKbps(self, minEntryUpstreamBandwidthKbps: int | java.jint | java.lang.Integer, minExitUpstreamBandwidthKbps: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setMms(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setOperatorPlmnIds(self, operatorPlmnIds: java.util.Set[java.lang.String], /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setOpportunistic(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setRcs(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setRoaming(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...
        def setSimSpecificCarrierIds(self, simSpecificCarrierIds: java.util.Set[java.lang.Integer], /) -> VcnCellUnderlyingNetworkTemplate.Builder: ...

class VcnConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VcnConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getGatewayConnectionConfigs(self) -> java.util.Set[VcnGatewayConnectionConfig]: ...
    def getRestrictedUnderlyingNetworkTransports(self) -> java.util.Set[java.lang.Integer]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def addGatewayConnectionConfig(self, gatewayConnectionConfig: VcnGatewayConnectionConfig, /) -> VcnConfig.Builder: ...
        def build(self) -> VcnConfig: ...
        def setRestrictedUnderlyingNetworkTransports(self, transports: java.util.Set[java.lang.Integer], /) -> VcnConfig.Builder: ...

class VcnGatewayConnectionConfig(java.lang.Object):
    MIN_UDP_PORT_4500_NAT_TIMEOUT_UNSET: typing.ClassVar[int] = ...
    VCN_GATEWAY_OPTION_ENABLE_DATA_STALL_RECOVERY_WITH_MOBILITY: typing.ClassVar[int] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getExposedCapabilities(self) -> java.chaquopy.JavaArrayJInt: ...
    def getGatewayConnectionName(self) -> str: ...
    def getMaxMtu(self) -> int: ...
    def getMinUdpPort4500NatTimeoutSeconds(self) -> int: ...
    def getRetryIntervalsMillis(self) -> java.chaquopy.JavaArrayJLong: ...
    def getVcnUnderlyingNetworkPriorities(self) -> java.util.List[VcnUnderlyingNetworkTemplate]: ...
    def hasGatewayOption(self, option: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hashCode(self) -> int: ...
    def isSafeModeEnabled(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self, gatewayConnectionName: str | java.lang.String, tunnelConnectionParams: android.net.ipsec.ike.IkeTunnelConnectionParams, /) -> None: ...
        def addExposedCapability(self, exposedCapability: int | java.jint | java.lang.Integer, /) -> VcnGatewayConnectionConfig.Builder: ...
        def addGatewayOption(self, option: int | java.jint | java.lang.Integer, /) -> VcnGatewayConnectionConfig.Builder: ...
        def build(self) -> VcnGatewayConnectionConfig: ...
        def removeExposedCapability(self, exposedCapability: int | java.jint | java.lang.Integer, /) -> VcnGatewayConnectionConfig.Builder: ...
        def removeGatewayOption(self, option: int | java.jint | java.lang.Integer, /) -> VcnGatewayConnectionConfig.Builder: ...
        def setMaxMtu(self, maxMtu: int | java.jint | java.lang.Integer, /) -> VcnGatewayConnectionConfig.Builder: ...
        def setMinUdpPort4500NatTimeoutSeconds(self, minUdpPort4500NatTimeoutSeconds: int | java.jint | java.lang.Integer, /) -> VcnGatewayConnectionConfig.Builder: ...
        def setRetryIntervalsMillis(self, retryIntervalsMs: java.chaquopy.JavaArrayJLong, /) -> VcnGatewayConnectionConfig.Builder: ...
        def setSafeModeEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> VcnGatewayConnectionConfig.Builder: ...
        def setVcnUnderlyingNetworkPriorities(self, underlyingNetworkTemplates: java.util.List[VcnUnderlyingNetworkTemplate], /) -> VcnGatewayConnectionConfig.Builder: ...

class VcnManager(java.lang.Object):
    VCN_ERROR_CODE_CONFIG_ERROR: typing.ClassVar[int] = ...
    VCN_ERROR_CODE_INTERNAL_ERROR: typing.ClassVar[int] = ...
    VCN_ERROR_CODE_NETWORK_ERROR: typing.ClassVar[int] = ...
    VCN_STATUS_CODE_ACTIVE: typing.ClassVar[int] = ...
    VCN_STATUS_CODE_INACTIVE: typing.ClassVar[int] = ...
    VCN_STATUS_CODE_NOT_CONFIGURED: typing.ClassVar[int] = ...
    VCN_STATUS_CODE_SAFE_MODE: typing.ClassVar[int] = ...
    def clearVcnConfig(self, subscriptionGroup: android.os.ParcelUuid, /) -> None: ...
    def getConfiguredSubscriptionGroups(self) -> java.util.List[android.os.ParcelUuid]: ...
    def registerVcnStatusCallback(self, subscriptionGroup: android.os.ParcelUuid, executor: java.util.concurrent.Executor, callback: VcnManager.VcnStatusCallback, /) -> None: ...
    def setVcnConfig(self, subscriptionGroup: android.os.ParcelUuid, config: VcnConfig, /) -> None: ...
    def unregisterVcnStatusCallback(self, callback: VcnManager.VcnStatusCallback, /) -> None: ...

    class VcnStatusCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onGatewayConnectionError(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: java.lang.Throwable, /) -> None: ...
        def onStatusChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class VcnUnderlyingNetworkTemplate(java.lang.Object):
    MATCH_ANY: typing.ClassVar[int] = ...
    MATCH_FORBIDDEN: typing.ClassVar[int] = ...
    MATCH_REQUIRED: typing.ClassVar[int] = ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMetered(self) -> int: ...
    def getMinEntryDownstreamBandwidthKbps(self) -> int: ...
    def getMinEntryUpstreamBandwidthKbps(self) -> int: ...
    def getMinExitDownstreamBandwidthKbps(self) -> int: ...
    def getMinExitUpstreamBandwidthKbps(self) -> int: ...
    def hashCode(self) -> int: ...

class VcnWifiUnderlyingNetworkTemplate(VcnUnderlyingNetworkTemplate):
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSsids(self) -> java.util.Set[java.lang.String]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> VcnWifiUnderlyingNetworkTemplate: ...
        def setMetered(self, matchCriteria: int | java.jint | java.lang.Integer, /) -> VcnWifiUnderlyingNetworkTemplate.Builder: ...
        def setMinDownstreamBandwidthKbps(self, minEntryDownstreamBandwidthKbps: int | java.jint | java.lang.Integer, minExitDownstreamBandwidthKbps: int | java.jint | java.lang.Integer, /) -> VcnWifiUnderlyingNetworkTemplate.Builder: ...
        def setMinUpstreamBandwidthKbps(self, minEntryUpstreamBandwidthKbps: int | java.jint | java.lang.Integer, minExitUpstreamBandwidthKbps: int | java.jint | java.lang.Integer, /) -> VcnWifiUnderlyingNetworkTemplate.Builder: ...
        def setSsids(self, ssids: java.util.Set[java.lang.String], /) -> VcnWifiUnderlyingNetworkTemplate.Builder: ...



import typing

import java.lang

class ImsRegistrationImplBase(java.lang.Object):
    REGISTRATION_TECH_3G: typing.ClassVar[int] = ...
    REGISTRATION_TECH_CROSS_SIM: typing.ClassVar[int] = ...
    REGISTRATION_TECH_IWLAN: typing.ClassVar[int] = ...
    REGISTRATION_TECH_LTE: typing.ClassVar[int] = ...
    REGISTRATION_TECH_NONE: typing.ClassVar[int] = ...
    REGISTRATION_TECH_NR: typing.ClassVar[int] = ...
